@@ -99,7 +99,7 @@ LibRecodeConverter::LibRecodeConverter(std::string const & inEnc, std::string co
 	,outer_(0)
 	,request_(0)
 {
-	std::string const encInOut(inEnc + ".." + outEnc);
+	std::string const encInOut(inEnc + ".." + outEnc + (sloppy ? "-translit" : ""));
 
 	if (! ((outer_ = ::recode_new_outer(1)) &&
 				 (request_ = ::recode_new_request(outer_)) &&
@@ -154,7 +154,6 @@ Conversion const * LibRecodeConverter::make(char const * const buf, size_t const
 			:task_(::recode_new_task(request))
 		{
 			// Task config
-			task_->strategy = RECODE_SEQUENCE_IN_MEMORY;
 			task_->fail_level = sloppy ? RECODE_INVALID_INPUT : RECODE_NOT_CANONICAL;
 
 			task_->input.buffer = buf;
