@@ -8,7 +8,7 @@
 #include <iostream>
 
 // C++ libraries
-#include <cc++/digest.h>
+#include <ucommon/secure.h>
 
 // Local
 #include "Time.hpp"
@@ -393,11 +393,7 @@ UI::Util::auto_ptr<unsigned char> XConversion::base64Decode(std::string const& m
 
 std::string md5sum(std::string const & data)
 {
-	ost::MD5Digest digest;
-	std::stringstream str;
-	digest << data;
-	str << digest;
-	return str.str();
+	return *(ucommon::Digest::md5(data.c_str()));
 }
 
 }}
